@@ -1,18 +1,17 @@
 from __future__ import annotations
 
+import importlib.resources
+import json
 import numbers
 from abc import abstractmethod
+from collections.abc import Iterable
 from copy import deepcopy
 from enum import Enum
 from functools import lru_cache
 from typing import (
     TYPE_CHECKING,
     Any,
-    Dict,
     Generic,
-    Iterable,
-    List,
-    Optional,
     Protocol,
     TypeVar,
     Union,
@@ -26,6 +25,21 @@ if TYPE_CHECKING:
     from pystac.item import Item
 
 
+def __getattr__(name: str) -> Any:
+    if name == "FIELDS_JSON_URL":
+        import warnings
+
+        warnings.warn(
+            "FIELDS_JSON_URL is deprecated and will be removed in v2",
+            DeprecationWarning,
+        )
+        return (
+            "https://cdn.jsdelivr.net/npm/@radiantearth/"
+            "stac-fields/fields-normalized.json"
+        )
+    raise AttributeError(f"module {__name__!r} has no attribute {name!r}")
+
+
 class _Comparable_x(Protocol):
     """Protocol for annotating comparable types.
 
@@ -34,7 +48,7 @@ class _Comparable_x(Protocol):
     """
 
     @abstractmethod
-    def __lt__(self: "T", x: "T") -> bool:
+    def __lt__(self: T, x: T) -> bool:
         return NotImplemented
 
 
@@ -46,7 +60,7 @@ class _Comparable_other(Protocol):
     """
 
     @abstractmethod
-    def __lt__(self: "T", other: "T") -> bool:
+    def __lt__(self: T, other: T) -> bool:
         return NotImplemented
 
 
@@ -61,7 +75,7 @@ class RangeSummary(Generic[T]):
         self.minimum = minimum
         self.maximum = maximum
 
-    def to_dict(self) -> Dict[str, Any]:
+    def to_dict(self) -> dict[str, Any]:
         return {"minimum": self.minimum, "maximum": self.maximum}
 
     def update_with_value(self, v: T) -> None:
@@ -69,7 +83,7 @@ class RangeSummary(Generic[T]):
         self.maximum = max(self.maximum, v)
 
     @classmethod
-    def from_dict(cls, d: Dict[str, Any]) -> RangeSummary[T]:
+    def from_dict(cls, d: dict[str, Any]) -> RangeSummary[T]:
         minimum: T = get_required(d.get("minimum"), "RangeSummary", "minimum")
         maximum: T = get_required(d.get("maximum"), "RangeSummary", "maximum")
         return cls(minimum=minimum, maximum=maximum)
@@ -84,13 +98,17 @@ class RangeSummary(Generic[T]):
         return self.to_dict().__repr__()
 
 
-FIELDS_JSON_URL = (
-    "https://cdn.jsdelivr.net/npm/@radiantearth/stac-fields/fields-normalized.json"
-)
-
-
 @lru_cache(maxsize=None)
-def _get_fields_json(url: str) -> Dict[str, Any]:
+def _get_fields_json(url: str | None) -> dict[str, Any]:
+    if url is None:
+        # Every time pystac is released this file gets pulled from
+        # https://cdn.jsdelivr.net/npm/@radiantearth/stac-fields/fields-normalized.json
+        jsonfields: dict[str, Any] = json.loads(
+            importlib.resources.files("pystac.static")
+            .joinpath("fields-normalized.json")
+            .read_text()
+        )
+        return jsonfields
     return pystac.StacIO.default().read_json(url)
 
 
@@ -104,47 +122,53 @@ class SummaryStrategy(Enum):
 
 class Summarizer:
     """The Summarizer computes summaries from values, following the definition of fields
-    to summarize provided in a json file.
+    to summarize.
 
-    For more information about the structure of the fields json file, see:
+    The fields to summarize can be provided as a JSON file or as a dictionary of
+    field names and SummaryStrategys. If nothing is provided, a default JSON file
+    will be used.
 
+    Only fields that are in the Item `properties` can be summarized.
+    Thus it is not possible to summarize the top-level fields such as `id` or `assets`.
+
+    For more information about the structure of the fields JSON file, see:
     https://github.com/stac-utils/stac-fields
 
+    The default JSON file used is a snapshot of the following file at the time of
+    the pystac release:
+    https://cdn.jsdelivr.net/npm/@radiantearth/stac-fields/fields-normalized.json
+
     Args:
-        fields (str): the path to the json file with field descriptions.
-        If no file is passed, a default one will be used.
+        fields: A string containing the path to the json file with field descriptions.
+            Alternatively, a dict with the field names as keys and SummaryStrategys
+            as values.
+            If nothing is passed, a default file with field descriptions will be used.
     """
 
-    summaryfields: Dict[str, SummaryStrategy]
+    summaryfields: dict[str, SummaryStrategy]
 
-    def __init__(self, fields: Optional[str] = None):
-        fieldspath = fields or FIELDS_JSON_URL
-        try:
-            jsonfields = _get_fields_json(fieldspath)
-        except Exception as e:
-            if fields is None:
-                raise Exception(
-                    "Could not read fields definition file at "
-                    f"{fields} or it is invalid.\n"
-                    "Try using a local fields definition file."
-                )
-            else:
-                raise e
-        self._set_field_definitions(jsonfields)
+    def __init__(self, fields: str | dict[str, SummaryStrategy] | None = None):
+        if isinstance(fields, dict):
+            self._set_field_definitions(fields)
+        else:
+            jsonfields = _get_fields_json(fields)
+            self._set_field_definitions(jsonfields["metadata"])
 
-    def _set_field_definitions(self, fields: Dict[str, Any]) -> None:
+    def _set_field_definitions(self, fields: dict[str, Any]) -> None:
         self.summaryfields = {}
-        for name, desc in fields["metadata"].items():
-            if isinstance(desc, dict):
+        for name, desc in fields.items():
+            strategy: SummaryStrategy = SummaryStrategy.DEFAULT
+            if isinstance(desc, SummaryStrategy):
+                strategy = desc
+            elif isinstance(desc, dict):
                 strategy_value = desc.get("summary", True)
                 try:
-                    strategy: SummaryStrategy = SummaryStrategy(strategy_value)
+                    strategy = SummaryStrategy(strategy_value)
                 except ValueError:
-                    strategy = SummaryStrategy.DEFAULT
-                if strategy != SummaryStrategy.DONT_SUMMARIZE:
-                    self.summaryfields[name] = strategy
-            else:
-                self.summaryfields[name] = SummaryStrategy.DEFAULT
+                    pass
+
+            if strategy != SummaryStrategy.DONT_SUMMARIZE:
+                self.summaryfields[name] = strategy
 
     def _update_with_item(self, summaries: Summaries, item: Item) -> None:
         for k, v in item.properties.items():
@@ -155,7 +179,7 @@ class Summarizer:
                     and isinstance(v, numbers.Number)
                     and not isinstance(v, bool)
                 ):
-                    rangesummary: Optional[RangeSummary[Any]] = summaries.get_range(k)
+                    rangesummary: RangeSummary[Any] | None = summaries.get_range(k)
                     if rangesummary is None:
                         summaries.add(k, RangeSummary(v, v))
                     else:
@@ -163,7 +187,7 @@ class Summarizer:
                 elif strategy == SummaryStrategy.ARRAY or (
                     strategy == SummaryStrategy.DEFAULT and isinstance(v, list)
                 ):
-                    listsummary: List[Any] = summaries.get_list(k) or []
+                    listsummary: list[Any] = summaries.get_list(k) or []
                     if not isinstance(v, list):
                         v = [v]
                     for element in v:
@@ -171,16 +195,16 @@ class Summarizer:
                             listsummary.append(element)
                     summaries.add(k, listsummary)
                 else:
-                    summary: List[Any] = summaries.get_list(k) or []
+                    summary: list[Any] = summaries.get_list(k) or []
                     if v not in summary:
                         summary.append(v)
                     summaries.add(k, summary)
 
-    def summarize(self, source: Union[Collection, Iterable[Item]]) -> Summaries:
+    def summarize(self, source: Collection | Iterable[Item]) -> Summaries:
         """Creates summaries from items"""
         summaries = Summaries.empty()
         if isinstance(source, pystac.Collection):
-            for item in source.get_all_items():
+            for item in source.get_items(recursive=True):
                 self._update_with_item(summaries, item)
         else:
             for item in source:
@@ -193,16 +217,16 @@ DEFAULT_MAXCOUNT = 25
 
 
 class Summaries:
-    _summaries: Dict[str, Any]
+    _summaries: dict[str, Any]
 
-    lists: Dict[str, List[Any]]
-    other: Dict[str, Any]
-    ranges: Dict[str, RangeSummary[Any]]
-    schemas: Dict[str, Dict[str, Any]]
+    lists: dict[str, list[Any]]
+    other: dict[str, Any]
+    ranges: dict[str, RangeSummary[Any]]
+    schemas: dict[str, dict[str, Any]]
     maxcount: int
 
     def __init__(
-        self, summaries: Dict[str, Any], maxcount: int = DEFAULT_MAXCOUNT
+        self, summaries: dict[str, Any], maxcount: int = DEFAULT_MAXCOUNT
     ) -> None:
         self._summaries = summaries
         self.maxcount = maxcount
@@ -215,19 +239,19 @@ class Summaries:
         for prop_key, summary in summaries.items():
             self.add(prop_key, summary)
 
-    def get_list(self, prop: str) -> Optional[List[Any]]:
+    def get_list(self, prop: str) -> list[Any] | None:
         return self.lists.get(prop)
 
-    def get_range(self, prop: str) -> Optional[RangeSummary[Any]]:
+    def get_range(self, prop: str) -> RangeSummary[Any] | None:
         return self.ranges.get(prop)
 
-    def get_schema(self, prop: str) -> Optional[Dict[str, Any]]:
+    def get_schema(self, prop: str) -> dict[str, Any] | None:
         return self.schemas.get(prop)
 
     def add(
         self,
         prop_key: str,
-        summary: Union[List[Any], RangeSummary[Any], Dict[str, Any]],
+        summary: list[Any] | RangeSummary[Any] | dict[str, Any],
     ) -> None:
         if isinstance(summary, list):
             self.lists[prop_key] = summary
@@ -295,7 +319,7 @@ class Summaries:
         summaries.schemas = deepcopy(self.schemas)
         return summaries
 
-    def to_dict(self) -> Dict[str, Any]:
+    def to_dict(self) -> dict[str, Any]:
         return {
             **{k: v for k, v in self.lists.items() if len(v) < self.maxcount},
             **{k: v.to_dict() for k, v in self.ranges.items()},
